Neural networks :code:`kooplearn.nn`
================================================

.. currentmodule:: kooplearn.nn

Main module: :code:`kooplearn.nn`
--------------------------------

Score functions
~~~~~~~~~~~~~~~

.. autoclass:: kooplearn.nn.DPLoss
    :members:

.. autoclass:: kooplearn.nn.VAMPLoss
    :members:


Functional: :code:`kooplearn.nn.functional`
-------------------------------------------

Score & loss functions
~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: kooplearn.nn.functional.vamp_score

.. autofunction:: kooplearn.nn.functional.deepprojection_score

.. autofunction:: kooplearn.nn.functional.log_fro_metric_deformation_loss


Linear algebra utilities
~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: kooplearn.nn.functional.covariance

.. autofunction:: kooplearn.nn.functional.sqrtmh

Bibliography
------------

.. footbibliography::